<script type="text/javascript">
    var _kmq = _kmq || [];
        function _kms(u) {
            setTimeout(function() {
                var s = document.createElement('script');
                var f = document.getElementsByTagName('script')[0];
                s.type = 'text/javascript';
                s.async = true;
                s.src = u;
                f.parentNode.insertBefore(s, f);
            }, 1);
        }
        _kms('//i.kissmetrics.com/i.js');
        _kms('//doug1izaerwt3.cloudfront.net/{{ KISSMETRICS_API_KEY }}.1.js');

    
        {% if identify_kiss %}
        _kmq.push(['identify', '{{ visitor_id }}']);
        {% endif %}
</script>
